@@ -1,4 +1,5 @@
-import random
+# special import since edX uses random2 as random
+import random2 as random
 
 class utils:
     """
@@ -9,6 +10,7 @@ class utils:
         Attempts to pull the anonymous_student_id if it exists and set it as the random seed
 
         Takes in:
+
         - `anonymous_student_id`:
             - Type: hex int
             - What: edX AID
